@@ -17,6 +17,7 @@ from ..auth.api_key_manager import APIKeyManager
 from ..core import SingleAgent
 from .code_commands import code as code_command
 from .knowledge_commands import knowledge_cli
+from .todo_commands import todo_group
 
 # Try to import Rich for enhanced visuals, fallback to basic if not available
 try:
@@ -42,6 +43,9 @@ def cli():
 # Add the code command to the CLI
 cli.add_command(code_command)
 
+# Add the todo command to the CLI
+cli.add_command(todo_group)
+
 
 @cli.command()
 @click.argument("query", required=False)
