@@ -240,7 +240,7 @@ class SingleAgent:
                             for entry in high_relevance_entries[:3]  # Use top 3 entries
                         ])
                         
-                        knowledge_prompt = f"""Based on the following knowledge base information, please provide a comprehensive answer to the user's question. If the knowledge base information fully answers the question, provide a complete response. If additional information might be helpful, mention that tools could be used for more details.
+                        knowledge_prompt = f"""Based on the following knowledge base information, please provide a clear, helpful answer to the user's question. If the knowledge base information fully answers the question, provide a direct response. If additional information might be helpful, mention that tools could be used for more details.
 
 KNOWLEDGE BASE INFORMATION:
 {knowledge_context}
