@@ -172,7 +172,7 @@ class SmartOrchestrator:
         llm = get_llm()
         
         # Use custom system message from context if available, otherwise fallback to default
-        system_prompt = context.get('system_message', "You are a helpful AI assistant. Provide clear, accurate, and concise responses to user queries.")
+        system_prompt = context.get('system_message', "You are a helpful AI assistant. Provide clear, accurate, and concise responses. Be conversational and natural - avoid being overly verbose or repetitive. Give focused, direct answers unless the user specifically asks for detailed explanations.")
         
         # Include memory context if available - integrate naturally without mentioning it
         memory_context = context.get('memory_context', '')
@@ -261,8 +261,8 @@ class SmartOrchestrator:
         Tool Used: {tool_name}
         Tool Result: {tool_result}
         
-        Synthesize this information into a comprehensive, helpful response for the user.
-        Focus on directly answering their question using the tool results.
+        Synthesize this information into a helpful, concise response for the user.
+        Focus on directly answering their question using the tool results. Be clear and to the point.
         """
         
         messages = [
@@ -372,8 +372,8 @@ class SmartOrchestrator:
         Execution Log: {execution_log}
         Tool Results: {json.dumps(results, indent=2)}
         
-        Synthesize all these results into a comprehensive final response.
-        Address the user's original query using insights from all tool executions.
+        Synthesize all these results into a clear, focused final response.
+        Address the user's original query using insights from all tool executions. Be concise and direct.
         """
         
         messages = [
@@ -447,9 +447,9 @@ class SmartOrchestrator:
         User Query: "{query}"
         Parallel Tool Results: {json.dumps(results, indent=2)}
         
-        Synthesize these parallel results into a coherent, comprehensive response.
+        Synthesize these parallel results into a coherent, focused response.
         Address any conflicts or redundancies in the results.
-        Provide a unified answer to the user's query.
+        Provide a unified, concise answer to the user's query.
         """
         
         messages = [
@@ -536,7 +536,7 @@ class SmartOrchestrator:
                 Conversation History: {conversation_history}
                 Tools Used: {tools_used}
                 
-                Provide a comprehensive final answer to the original query.
+                Provide a clear, direct final answer to the original query.
                 """
                 
                 messages = [
